Class AbortDocumentVersionUploadRequest
java.lang.Object
software.amazon.awssdk.core.SdkRequest
software.amazon.awssdk.awscore.AwsRequest
software.amazon.awssdk.services.workdocs.model.WorkDocsRequest
software.amazon.awssdk.services.workdocs.model.AbortDocumentVersionUploadRequest
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<AbortDocumentVersionUploadRequest.Builder,AbortDocumentVersionUploadRequest>
@Generated("software.amazon.awssdk:codegen")
public final class AbortDocumentVersionUploadRequest
extends WorkDocsRequest
implements ToCopyableBuilder<AbortDocumentVersionUploadRequest.Builder,AbortDocumentVersionUploadRequest>
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionfinal StringAmazon WorkDocs authentication token.builder()final StringThe ID of the document.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()static Class<? extends AbortDocumentVersionUploadRequest.Builder>final StringtoString()Returns a string representation of this object.final StringThe ID of the version.Methods inherited from class software.amazon.awssdk.awscore.AwsRequest
overrideConfigurationMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
authenticationToken
Amazon WorkDocs authentication token. Not required when using Amazon Web Services administrator credentials to access the API.
- Returns:
- Amazon WorkDocs authentication token. Not required when using Amazon Web Services administrator credentials to access the API.
-
documentId
The ID of the document.
- Returns:
- The ID of the document.
-
versionId
The ID of the version.
- Returns:
- The ID of the version.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<AbortDocumentVersionUploadRequest.Builder,AbortDocumentVersionUploadRequest> - Specified by:
toBuilderin classWorkDocsRequest
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsRequest
-
equals
- Overrides:
equalsin classAwsRequest
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkRequest
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-