Class AddResourcePermissionsRequest
java.lang.Object
software.amazon.awssdk.core.SdkRequest
software.amazon.awssdk.awscore.AwsRequest
software.amazon.awssdk.services.workdocs.model.WorkDocsRequest
software.amazon.awssdk.services.workdocs.model.AddResourcePermissionsRequest
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<AddResourcePermissionsRequest.Builder,AddResourcePermissionsRequest>
@Generated("software.amazon.awssdk:codegen")
public final class AddResourcePermissionsRequest
extends WorkDocsRequest
implements ToCopyableBuilder<AddResourcePermissionsRequest.Builder,AddResourcePermissionsRequest>
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionfinal StringAmazon WorkDocs authentication token.builder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final booleanFor responses, this returns true if the service returned a value for the Principals property.final NotificationOptionsThe notification options.final List<SharePrincipal>The users, groups, or organization being granted permission.final StringThe ID of the resource.static Class<? extends AddResourcePermissionsRequest.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class software.amazon.awssdk.awscore.AwsRequest
overrideConfigurationMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
authenticationToken
Amazon WorkDocs authentication token. Not required when using Amazon Web Services administrator credentials to access the API.
- Returns:
- Amazon WorkDocs authentication token. Not required when using Amazon Web Services administrator credentials to access the API.
-
resourceId
The ID of the resource.
- Returns:
- The ID of the resource.
-
hasPrincipals
public final boolean hasPrincipals()For responses, this returns true if the service returned a value for the Principals property. This DOES NOT check that the value is non-empty (for which, you should check theisEmpty()method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified. -
principals
The users, groups, or organization being granted permission.
Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.
This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the
hasPrincipals()method.- Returns:
- The users, groups, or organization being granted permission.
-
notificationOptions
The notification options.
- Returns:
- The notification options.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<AddResourcePermissionsRequest.Builder,AddResourcePermissionsRequest> - Specified by:
toBuilderin classWorkDocsRequest
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsRequest
-
equals
- Overrides:
equalsin classAwsRequest
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkRequest
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-