Class Comment
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<Comment.Builder,Comment>
Describes a comment.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionstatic Comment.Builderbuilder()final StringThe ID of the comment.final UserThe details of the user who made the comment.final InstantThe time that the comment was created.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final StringparentId()The ID of the parent comment.final StringIf the comment is a reply to another user's comment, this field contains the user ID of the user being replied to.static Class<? extends Comment.Builder>final CommentStatusTypestatus()The status of the comment.final StringThe status of the comment.final Stringtext()The text of the comment.final StringthreadId()The ID of the root comment in the thread.final StringtoString()Returns a string representation of this object.final CommentVisibilityTypeThe visibility of the comment.final StringThe visibility of the comment.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
commentId
The ID of the comment.
- Returns:
- The ID of the comment.
-
parentId
The ID of the parent comment.
- Returns:
- The ID of the parent comment.
-
threadId
The ID of the root comment in the thread.
- Returns:
- The ID of the root comment in the thread.
-
text
The text of the comment.
- Returns:
- The text of the comment.
-
contributor
The details of the user who made the comment.
- Returns:
- The details of the user who made the comment.
-
createdTimestamp
The time that the comment was created.
- Returns:
- The time that the comment was created.
-
status
The status of the comment.
If the service returns an enum value that is not available in the current SDK version,
statuswill returnCommentStatusType.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromstatusAsString().- Returns:
- The status of the comment.
- See Also:
-
statusAsString
The status of the comment.
If the service returns an enum value that is not available in the current SDK version,
statuswill returnCommentStatusType.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromstatusAsString().- Returns:
- The status of the comment.
- See Also:
-
visibility
The visibility of the comment. Options are either PRIVATE, where the comment is visible only to the comment author and document owner and co-owners, or PUBLIC, where the comment is visible to document owners, co-owners, and contributors.
If the service returns an enum value that is not available in the current SDK version,
visibilitywill returnCommentVisibilityType.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromvisibilityAsString().- Returns:
- The visibility of the comment. Options are either PRIVATE, where the comment is visible only to the comment author and document owner and co-owners, or PUBLIC, where the comment is visible to document owners, co-owners, and contributors.
- See Also:
-
visibilityAsString
The visibility of the comment. Options are either PRIVATE, where the comment is visible only to the comment author and document owner and co-owners, or PUBLIC, where the comment is visible to document owners, co-owners, and contributors.
If the service returns an enum value that is not available in the current SDK version,
visibilitywill returnCommentVisibilityType.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromvisibilityAsString().- Returns:
- The visibility of the comment. Options are either PRIVATE, where the comment is visible only to the comment author and document owner and co-owners, or PUBLIC, where the comment is visible to document owners, co-owners, and contributors.
- See Also:
-
recipientId
If the comment is a reply to another user's comment, this field contains the user ID of the user being replied to.
- Returns:
- If the comment is a reply to another user's comment, this field contains the user ID of the user being replied to.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<Comment.Builder,Comment>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-