Class CommentMetadata
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<CommentMetadata.Builder,CommentMetadata>
Describes the metadata of a comment.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionstatic CommentMetadata.Builderbuilder()final StringThe ID of the comment.final CommentStatusTypeThe status of the comment.final StringThe status of the comment.final UserThe user who made the comment.final StringThe ID of the user who made the comment.final InstantThe timestamp that the comment was created.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final StringThe ID of the user being replied to.static Class<? extends CommentMetadata.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
commentId
The ID of the comment.
- Returns:
- The ID of the comment.
-
contributor
The user who made the comment.
- Returns:
- The user who made the comment.
-
createdTimestamp
The timestamp that the comment was created.
- Returns:
- The timestamp that the comment was created.
-
commentStatus
The status of the comment.
If the service returns an enum value that is not available in the current SDK version,
commentStatuswill returnCommentStatusType.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromcommentStatusAsString().- Returns:
- The status of the comment.
- See Also:
-
commentStatusAsString
The status of the comment.
If the service returns an enum value that is not available in the current SDK version,
commentStatuswill returnCommentStatusType.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromcommentStatusAsString().- Returns:
- The status of the comment.
- See Also:
-
recipientId
The ID of the user being replied to.
- Returns:
- The ID of the user being replied to.
-
contributorId
The ID of the user who made the comment.
- Returns:
- The ID of the user who made the comment.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<CommentMetadata.Builder,CommentMetadata>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-