Class CreateCustomMetadataRequest
java.lang.Object
software.amazon.awssdk.core.SdkRequest
software.amazon.awssdk.awscore.AwsRequest
software.amazon.awssdk.services.workdocs.model.WorkDocsRequest
software.amazon.awssdk.services.workdocs.model.CreateCustomMetadataRequest
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<CreateCustomMetadataRequest.Builder,CreateCustomMetadataRequest>
@Generated("software.amazon.awssdk:codegen")
public final class CreateCustomMetadataRequest
extends WorkDocsRequest
implements ToCopyableBuilder<CreateCustomMetadataRequest.Builder,CreateCustomMetadataRequest>
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionfinal StringAmazon WorkDocs authentication token.builder()Custom metadata in the form of name-value pairs.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final booleanFor responses, this returns true if the service returned a value for the CustomMetadata property.final inthashCode()final StringThe ID of the resource.static Class<? extends CreateCustomMetadataRequest.Builder>final StringtoString()Returns a string representation of this object.final StringThe ID of the version, if the custom metadata is being added to a document version.Methods inherited from class software.amazon.awssdk.awscore.AwsRequest
overrideConfigurationMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
authenticationToken
Amazon WorkDocs authentication token. Not required when using Amazon Web Services administrator credentials to access the API.
- Returns:
- Amazon WorkDocs authentication token. Not required when using Amazon Web Services administrator credentials to access the API.
-
resourceId
The ID of the resource.
- Returns:
- The ID of the resource.
-
versionId
The ID of the version, if the custom metadata is being added to a document version.
- Returns:
- The ID of the version, if the custom metadata is being added to a document version.
-
hasCustomMetadata
public final boolean hasCustomMetadata()For responses, this returns true if the service returned a value for the CustomMetadata property. This DOES NOT check that the value is non-empty (for which, you should check theisEmpty()method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified. -
customMetadata
Custom metadata in the form of name-value pairs.
Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.
This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the
hasCustomMetadata()method.- Returns:
- Custom metadata in the form of name-value pairs.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<CreateCustomMetadataRequest.Builder,CreateCustomMetadataRequest> - Specified by:
toBuilderin classWorkDocsRequest
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsRequest
-
equals
- Overrides:
equalsin classAwsRequest
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkRequest
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-