Interface CreateCustomMetadataRequest.Builder
- All Superinterfaces:
AwsRequest.Builder,Buildable,CopyableBuilder<CreateCustomMetadataRequest.Builder,,CreateCustomMetadataRequest> SdkBuilder<CreateCustomMetadataRequest.Builder,,CreateCustomMetadataRequest> SdkPojo,SdkRequest.Builder,WorkDocsRequest.Builder
- Enclosing class:
- CreateCustomMetadataRequest
@Mutable
@NotThreadSafe
public static interface CreateCustomMetadataRequest.Builder
extends WorkDocsRequest.Builder, SdkPojo, CopyableBuilder<CreateCustomMetadataRequest.Builder,CreateCustomMetadataRequest>
-
Method Summary
Modifier and TypeMethodDescriptionauthenticationToken(String authenticationToken) Amazon WorkDocs authentication token.customMetadata(Map<String, String> customMetadata) Custom metadata in the form of name-value pairs.overrideConfiguration(Consumer<AwsRequestOverrideConfiguration.Builder> builderConsumer) overrideConfiguration(AwsRequestOverrideConfiguration overrideConfiguration) resourceId(String resourceId) The ID of the resource.The ID of the version, if the custom metadata is being added to a document version.Methods inherited from interface software.amazon.awssdk.awscore.AwsRequest.Builder
overrideConfigurationMethods inherited from interface software.amazon.awssdk.utils.builder.CopyableBuilder
copyMethods inherited from interface software.amazon.awssdk.utils.builder.SdkBuilder
applyMutation, buildMethods inherited from interface software.amazon.awssdk.core.SdkPojo
equalsBySdkFields, sdkFieldNameToField, sdkFieldsMethods inherited from interface software.amazon.awssdk.services.workdocs.model.WorkDocsRequest.Builder
build
-
Method Details
-
authenticationToken
Amazon WorkDocs authentication token. Not required when using Amazon Web Services administrator credentials to access the API.
- Parameters:
authenticationToken- Amazon WorkDocs authentication token. Not required when using Amazon Web Services administrator credentials to access the API.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
resourceId
The ID of the resource.
- Parameters:
resourceId- The ID of the resource.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
versionId
The ID of the version, if the custom metadata is being added to a document version.
- Parameters:
versionId- The ID of the version, if the custom metadata is being added to a document version.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
customMetadata
Custom metadata in the form of name-value pairs.
- Parameters:
customMetadata- Custom metadata in the form of name-value pairs.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
overrideConfiguration
CreateCustomMetadataRequest.Builder overrideConfiguration(AwsRequestOverrideConfiguration overrideConfiguration) - Specified by:
overrideConfigurationin interfaceAwsRequest.Builder
-
overrideConfiguration
CreateCustomMetadataRequest.Builder overrideConfiguration(Consumer<AwsRequestOverrideConfiguration.Builder> builderConsumer) - Specified by:
overrideConfigurationin interfaceAwsRequest.Builder
-