Interface CreateNotificationSubscriptionRequest.Builder
- All Superinterfaces:
AwsRequest.Builder,Buildable,CopyableBuilder<CreateNotificationSubscriptionRequest.Builder,,CreateNotificationSubscriptionRequest> SdkBuilder<CreateNotificationSubscriptionRequest.Builder,,CreateNotificationSubscriptionRequest> SdkPojo,SdkRequest.Builder,WorkDocsRequest.Builder
- Enclosing class:
- CreateNotificationSubscriptionRequest
@Mutable
@NotThreadSafe
public static interface CreateNotificationSubscriptionRequest.Builder
extends WorkDocsRequest.Builder, SdkPojo, CopyableBuilder<CreateNotificationSubscriptionRequest.Builder,CreateNotificationSubscriptionRequest>
-
Method Summary
Modifier and TypeMethodDescriptionThe endpoint to receive the notifications.organizationId(String organizationId) The ID of the organization.overrideConfiguration(Consumer<AwsRequestOverrideConfiguration.Builder> builderConsumer) overrideConfiguration(AwsRequestOverrideConfiguration overrideConfiguration) The protocol to use.protocol(SubscriptionProtocolType protocol) The protocol to use.subscriptionType(String subscriptionType) The notification type.subscriptionType(SubscriptionType subscriptionType) The notification type.Methods inherited from interface software.amazon.awssdk.awscore.AwsRequest.Builder
overrideConfigurationMethods inherited from interface software.amazon.awssdk.utils.builder.CopyableBuilder
copyMethods inherited from interface software.amazon.awssdk.utils.builder.SdkBuilder
applyMutation, buildMethods inherited from interface software.amazon.awssdk.core.SdkPojo
equalsBySdkFields, sdkFieldNameToField, sdkFieldsMethods inherited from interface software.amazon.awssdk.services.workdocs.model.WorkDocsRequest.Builder
build
-
Method Details
-
organizationId
The ID of the organization.
- Parameters:
organizationId- The ID of the organization.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
endpoint
The endpoint to receive the notifications. If the protocol is HTTPS, the endpoint is a URL that begins with
https.- Parameters:
endpoint- The endpoint to receive the notifications. If the protocol is HTTPS, the endpoint is a URL that begins withhttps.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
protocol
The protocol to use. The supported value is https, which delivers JSON-encoded messages using HTTPS POST.
- Parameters:
protocol- The protocol to use. The supported value is https, which delivers JSON-encoded messages using HTTPS POST.- Returns:
- Returns a reference to this object so that method calls can be chained together.
- See Also:
-
protocol
The protocol to use. The supported value is https, which delivers JSON-encoded messages using HTTPS POST.
- Parameters:
protocol- The protocol to use. The supported value is https, which delivers JSON-encoded messages using HTTPS POST.- Returns:
- Returns a reference to this object so that method calls can be chained together.
- See Also:
-
subscriptionType
The notification type.
- Parameters:
subscriptionType- The notification type.- Returns:
- Returns a reference to this object so that method calls can be chained together.
- See Also:
-
subscriptionType
The notification type.
- Parameters:
subscriptionType- The notification type.- Returns:
- Returns a reference to this object so that method calls can be chained together.
- See Also:
-
overrideConfiguration
CreateNotificationSubscriptionRequest.Builder overrideConfiguration(AwsRequestOverrideConfiguration overrideConfiguration) - Specified by:
overrideConfigurationin interfaceAwsRequest.Builder
-
overrideConfiguration
CreateNotificationSubscriptionRequest.Builder overrideConfiguration(Consumer<AwsRequestOverrideConfiguration.Builder> builderConsumer) - Specified by:
overrideConfigurationin interfaceAwsRequest.Builder
-