Class CreateUserRequest
java.lang.Object
software.amazon.awssdk.core.SdkRequest
software.amazon.awssdk.awscore.AwsRequest
software.amazon.awssdk.services.workdocs.model.WorkDocsRequest
software.amazon.awssdk.services.workdocs.model.CreateUserRequest
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<CreateUserRequest.Builder,CreateUserRequest>
@Generated("software.amazon.awssdk:codegen")
public final class CreateUserRequest
extends WorkDocsRequest
implements ToCopyableBuilder<CreateUserRequest.Builder,CreateUserRequest>
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionfinal StringAmazon WorkDocs authentication token.static CreateUserRequest.Builderbuilder()final StringThe email address of the user.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final StringThe given name of the user.final inthashCode()final StringThe ID of the organization.final Stringpassword()The password of the user.static Class<? extends CreateUserRequest.Builder>final StorageRuleTypeThe amount of storage for the user.final Stringsurname()The surname of the user.final StringThe time zone ID of the user.final StringtoString()Returns a string representation of this object.final Stringusername()The login name of the user.Methods inherited from class software.amazon.awssdk.awscore.AwsRequest
overrideConfigurationMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
organizationId
The ID of the organization.
- Returns:
- The ID of the organization.
-
username
The login name of the user.
- Returns:
- The login name of the user.
-
emailAddress
The email address of the user.
- Returns:
- The email address of the user.
-
givenName
The given name of the user.
- Returns:
- The given name of the user.
-
surname
The surname of the user.
- Returns:
- The surname of the user.
-
password
The password of the user.
- Returns:
- The password of the user.
-
timeZoneId
The time zone ID of the user.
- Returns:
- The time zone ID of the user.
-
storageRule
The amount of storage for the user.
- Returns:
- The amount of storage for the user.
-
authenticationToken
Amazon WorkDocs authentication token. Not required when using Amazon Web Services administrator credentials to access the API.
- Returns:
- Amazon WorkDocs authentication token. Not required when using Amazon Web Services administrator credentials to access the API.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<CreateUserRequest.Builder,CreateUserRequest> - Specified by:
toBuilderin classWorkDocsRequest
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsRequest
-
equals
- Overrides:
equalsin classAwsRequest
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkRequest
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-