Interface DeleteCommentRequest.Builder
- All Superinterfaces:
AwsRequest.Builder,Buildable,CopyableBuilder<DeleteCommentRequest.Builder,,DeleteCommentRequest> SdkBuilder<DeleteCommentRequest.Builder,,DeleteCommentRequest> SdkPojo,SdkRequest.Builder,WorkDocsRequest.Builder
- Enclosing class:
- DeleteCommentRequest
@Mutable
@NotThreadSafe
public static interface DeleteCommentRequest.Builder
extends WorkDocsRequest.Builder, SdkPojo, CopyableBuilder<DeleteCommentRequest.Builder,DeleteCommentRequest>
-
Method Summary
Modifier and TypeMethodDescriptionauthenticationToken(String authenticationToken) Amazon WorkDocs authentication token.The ID of the comment.documentId(String documentId) The ID of the document.overrideConfiguration(Consumer<AwsRequestOverrideConfiguration.Builder> builderConsumer) overrideConfiguration(AwsRequestOverrideConfiguration overrideConfiguration) The ID of the document version.Methods inherited from interface software.amazon.awssdk.awscore.AwsRequest.Builder
overrideConfigurationMethods inherited from interface software.amazon.awssdk.utils.builder.CopyableBuilder
copyMethods inherited from interface software.amazon.awssdk.utils.builder.SdkBuilder
applyMutation, buildMethods inherited from interface software.amazon.awssdk.core.SdkPojo
equalsBySdkFields, sdkFieldNameToField, sdkFieldsMethods inherited from interface software.amazon.awssdk.services.workdocs.model.WorkDocsRequest.Builder
build
-
Method Details
-
authenticationToken
Amazon WorkDocs authentication token. Not required when using Amazon Web Services administrator credentials to access the API.
- Parameters:
authenticationToken- Amazon WorkDocs authentication token. Not required when using Amazon Web Services administrator credentials to access the API.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
documentId
The ID of the document.
- Parameters:
documentId- The ID of the document.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
versionId
The ID of the document version.
- Parameters:
versionId- The ID of the document version.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
commentId
The ID of the comment.
- Parameters:
commentId- The ID of the comment.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
overrideConfiguration
DeleteCommentRequest.Builder overrideConfiguration(AwsRequestOverrideConfiguration overrideConfiguration) - Specified by:
overrideConfigurationin interfaceAwsRequest.Builder
-
overrideConfiguration
DeleteCommentRequest.Builder overrideConfiguration(Consumer<AwsRequestOverrideConfiguration.Builder> builderConsumer) - Specified by:
overrideConfigurationin interfaceAwsRequest.Builder
-