Class DeleteDocumentVersionRequest
java.lang.Object
software.amazon.awssdk.core.SdkRequest
software.amazon.awssdk.awscore.AwsRequest
software.amazon.awssdk.services.workdocs.model.WorkDocsRequest
software.amazon.awssdk.services.workdocs.model.DeleteDocumentVersionRequest
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<DeleteDocumentVersionRequest.Builder,DeleteDocumentVersionRequest>
@Generated("software.amazon.awssdk:codegen")
public final class DeleteDocumentVersionRequest
extends WorkDocsRequest
implements ToCopyableBuilder<DeleteDocumentVersionRequest.Builder,DeleteDocumentVersionRequest>
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionfinal StringAmazon WorkDocs authentication token.builder()final BooleanDeletes all versions of a document prior to the current version.final StringThe ID of the document associated with the version being deleted.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()static Class<? extends DeleteDocumentVersionRequest.Builder>final StringtoString()Returns a string representation of this object.final StringThe ID of the version being deleted.Methods inherited from class software.amazon.awssdk.awscore.AwsRequest
overrideConfigurationMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
authenticationToken
Amazon WorkDocs authentication token. Not required when using Amazon Web Services administrator credentials to access the API.
- Returns:
- Amazon WorkDocs authentication token. Not required when using Amazon Web Services administrator credentials to access the API.
-
documentId
The ID of the document associated with the version being deleted.
- Returns:
- The ID of the document associated with the version being deleted.
-
versionId
The ID of the version being deleted.
- Returns:
- The ID of the version being deleted.
-
deletePriorVersions
Deletes all versions of a document prior to the current version.
- Returns:
- Deletes all versions of a document prior to the current version.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<DeleteDocumentVersionRequest.Builder,DeleteDocumentVersionRequest> - Specified by:
toBuilderin classWorkDocsRequest
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsRequest
-
equals
- Overrides:
equalsin classAwsRequest
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkRequest
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-