Class DeleteFolderContentsRequest
java.lang.Object
software.amazon.awssdk.core.SdkRequest
software.amazon.awssdk.awscore.AwsRequest
software.amazon.awssdk.services.workdocs.model.WorkDocsRequest
software.amazon.awssdk.services.workdocs.model.DeleteFolderContentsRequest
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<DeleteFolderContentsRequest.Builder,DeleteFolderContentsRequest>
@Generated("software.amazon.awssdk:codegen")
public final class DeleteFolderContentsRequest
extends WorkDocsRequest
implements ToCopyableBuilder<DeleteFolderContentsRequest.Builder,DeleteFolderContentsRequest>
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionfinal StringAmazon WorkDocs authentication token.builder()final booleanfinal booleanequalsBySdkFields(Object obj) final StringfolderId()The ID of the folder.final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()static Class<? extends DeleteFolderContentsRequest.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class software.amazon.awssdk.awscore.AwsRequest
overrideConfigurationMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
authenticationToken
Amazon WorkDocs authentication token. Not required when using Amazon Web Services administrator credentials to access the API.
- Returns:
- Amazon WorkDocs authentication token. Not required when using Amazon Web Services administrator credentials to access the API.
-
folderId
The ID of the folder.
- Returns:
- The ID of the folder.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<DeleteFolderContentsRequest.Builder,DeleteFolderContentsRequest> - Specified by:
toBuilderin classWorkDocsRequest
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsRequest
-
equals
- Overrides:
equalsin classAwsRequest
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkRequest
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-