Class DeleteLabelsRequest
java.lang.Object
software.amazon.awssdk.core.SdkRequest
software.amazon.awssdk.awscore.AwsRequest
software.amazon.awssdk.services.workdocs.model.WorkDocsRequest
software.amazon.awssdk.services.workdocs.model.DeleteLabelsRequest
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<DeleteLabelsRequest.Builder,DeleteLabelsRequest>
@Generated("software.amazon.awssdk:codegen")
public final class DeleteLabelsRequest
extends WorkDocsRequest
implements ToCopyableBuilder<DeleteLabelsRequest.Builder,DeleteLabelsRequest>
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionfinal StringAmazon WorkDocs authentication token.static DeleteLabelsRequest.Builderbuilder()final BooleanFlag to request removal of all labels from the specified resource.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final booleanFor responses, this returns true if the service returned a value for the Labels property.labels()List of labels to delete from the resource.final StringThe ID of the resource.static Class<? extends DeleteLabelsRequest.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class software.amazon.awssdk.awscore.AwsRequest
overrideConfigurationMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
resourceId
The ID of the resource.
- Returns:
- The ID of the resource.
-
authenticationToken
Amazon WorkDocs authentication token. Not required when using Amazon Web Services administrator credentials to access the API.
- Returns:
- Amazon WorkDocs authentication token. Not required when using Amazon Web Services administrator credentials to access the API.
-
hasLabels
public final boolean hasLabels()For responses, this returns true if the service returned a value for the Labels property. This DOES NOT check that the value is non-empty (for which, you should check theisEmpty()method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified. -
labels
List of labels to delete from the resource.
Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.
This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the
hasLabels()method.- Returns:
- List of labels to delete from the resource.
-
deleteAll
Flag to request removal of all labels from the specified resource.
- Returns:
- Flag to request removal of all labels from the specified resource.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<DeleteLabelsRequest.Builder,DeleteLabelsRequest> - Specified by:
toBuilderin classWorkDocsRequest
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsRequest
-
equals
- Overrides:
equalsin classAwsRequest
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkRequest
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-