Class DescribeDocumentVersionsRequest

All Implemented Interfaces:
SdkPojo, ToCopyableBuilder<DescribeDocumentVersionsRequest.Builder,DescribeDocumentVersionsRequest>

@Generated("software.amazon.awssdk:codegen") public final class DescribeDocumentVersionsRequest extends WorkDocsRequest implements ToCopyableBuilder<DescribeDocumentVersionsRequest.Builder,DescribeDocumentVersionsRequest>
  • Method Details

    • authenticationToken

      public final String authenticationToken()

      Amazon WorkDocs authentication token. Not required when using Amazon Web Services administrator credentials to access the API.

      Returns:
      Amazon WorkDocs authentication token. Not required when using Amazon Web Services administrator credentials to access the API.
    • documentId

      public final String documentId()

      The ID of the document.

      Returns:
      The ID of the document.
    • marker

      public final String marker()

      The marker for the next set of results. (You received this marker from a previous call.)

      Returns:
      The marker for the next set of results. (You received this marker from a previous call.)
    • limit

      public final Integer limit()

      The maximum number of versions to return with this call.

      Returns:
      The maximum number of versions to return with this call.
    • include

      public final String include()

      A comma-separated list of values. Specify "INITIALIZED" to include incomplete versions.

      Returns:
      A comma-separated list of values. Specify "INITIALIZED" to include incomplete versions.
    • fields

      public final String fields()

      Specify "SOURCE" to include initialized versions and a URL for the source document.

      Returns:
      Specify "SOURCE" to include initialized versions and a URL for the source document.
    • toBuilder

      Specified by:
      toBuilder in interface ToCopyableBuilder<DescribeDocumentVersionsRequest.Builder,DescribeDocumentVersionsRequest>
      Specified by:
      toBuilder in class WorkDocsRequest
    • builder

      public static DescribeDocumentVersionsRequest.Builder builder()
    • serializableBuilderClass

      public static Class<? extends DescribeDocumentVersionsRequest.Builder> serializableBuilderClass()
    • hashCode

      public final int hashCode()
      Overrides:
      hashCode in class AwsRequest
    • equals

      public final boolean equals(Object obj)
      Overrides:
      equals in class AwsRequest
    • equalsBySdkFields

      public final boolean equalsBySdkFields(Object obj)
      Specified by:
      equalsBySdkFields in interface SdkPojo
    • toString

      public final String toString()
      Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
      Overrides:
      toString in class Object
    • getValueForField

      public final <T> Optional<T> getValueForField(String fieldName, Class<T> clazz)
      Overrides:
      getValueForField in class SdkRequest
    • sdkFields

      public final List<SdkField<?>> sdkFields()
      Specified by:
      sdkFields in interface SdkPojo
    • sdkFieldNameToField

      public final Map<String,SdkField<?>> sdkFieldNameToField()
      Specified by:
      sdkFieldNameToField in interface SdkPojo