Interface DescribeFolderContentsRequest.Builder
- All Superinterfaces:
AwsRequest.Builder,Buildable,CopyableBuilder<DescribeFolderContentsRequest.Builder,,DescribeFolderContentsRequest> SdkBuilder<DescribeFolderContentsRequest.Builder,,DescribeFolderContentsRequest> SdkPojo,SdkRequest.Builder,WorkDocsRequest.Builder
- Enclosing class:
- DescribeFolderContentsRequest
@Mutable
@NotThreadSafe
public static interface DescribeFolderContentsRequest.Builder
extends WorkDocsRequest.Builder, SdkPojo, CopyableBuilder<DescribeFolderContentsRequest.Builder,DescribeFolderContentsRequest>
-
Method Summary
Modifier and TypeMethodDescriptionauthenticationToken(String authenticationToken) Amazon WorkDocs authentication token.The ID of the folder.The contents to include.The maximum number of items to return with this call.The marker for the next set of results.The order for the contents of the folder.The order for the contents of the folder.overrideConfiguration(Consumer<AwsRequestOverrideConfiguration.Builder> builderConsumer) overrideConfiguration(AwsRequestOverrideConfiguration overrideConfiguration) The sorting criteria.sort(ResourceSortType sort) The sorting criteria.The type of items.type(FolderContentType type) The type of items.Methods inherited from interface software.amazon.awssdk.awscore.AwsRequest.Builder
overrideConfigurationMethods inherited from interface software.amazon.awssdk.utils.builder.CopyableBuilder
copyMethods inherited from interface software.amazon.awssdk.utils.builder.SdkBuilder
applyMutation, buildMethods inherited from interface software.amazon.awssdk.core.SdkPojo
equalsBySdkFields, sdkFieldNameToField, sdkFieldsMethods inherited from interface software.amazon.awssdk.services.workdocs.model.WorkDocsRequest.Builder
build
-
Method Details
-
authenticationToken
Amazon WorkDocs authentication token. Not required when using Amazon Web Services administrator credentials to access the API.
- Parameters:
authenticationToken- Amazon WorkDocs authentication token. Not required when using Amazon Web Services administrator credentials to access the API.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
folderId
The ID of the folder.
- Parameters:
folderId- The ID of the folder.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
sort
The sorting criteria.
- Parameters:
sort- The sorting criteria.- Returns:
- Returns a reference to this object so that method calls can be chained together.
- See Also:
-
sort
The sorting criteria.
- Parameters:
sort- The sorting criteria.- Returns:
- Returns a reference to this object so that method calls can be chained together.
- See Also:
-
order
The order for the contents of the folder.
-
order
The order for the contents of the folder.
-
limit
The maximum number of items to return with this call.
- Parameters:
limit- The maximum number of items to return with this call.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
marker
The marker for the next set of results. This marker was received from a previous call.
- Parameters:
marker- The marker for the next set of results. This marker was received from a previous call.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
type
The type of items.
- Parameters:
type- The type of items.- Returns:
- Returns a reference to this object so that method calls can be chained together.
- See Also:
-
type
The type of items.
- Parameters:
type- The type of items.- Returns:
- Returns a reference to this object so that method calls can be chained together.
- See Also:
-
include
The contents to include. Specify "INITIALIZED" to include initialized documents.
- Parameters:
include- The contents to include. Specify "INITIALIZED" to include initialized documents.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
overrideConfiguration
DescribeFolderContentsRequest.Builder overrideConfiguration(AwsRequestOverrideConfiguration overrideConfiguration) - Specified by:
overrideConfigurationin interfaceAwsRequest.Builder
-
overrideConfiguration
DescribeFolderContentsRequest.Builder overrideConfiguration(Consumer<AwsRequestOverrideConfiguration.Builder> builderConsumer) - Specified by:
overrideConfigurationin interfaceAwsRequest.Builder
-