Class DescribeNotificationSubscriptionsRequest
java.lang.Object
software.amazon.awssdk.core.SdkRequest
software.amazon.awssdk.awscore.AwsRequest
software.amazon.awssdk.services.workdocs.model.WorkDocsRequest
software.amazon.awssdk.services.workdocs.model.DescribeNotificationSubscriptionsRequest
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<DescribeNotificationSubscriptionsRequest.Builder,DescribeNotificationSubscriptionsRequest>
@Generated("software.amazon.awssdk:codegen")
public final class DescribeNotificationSubscriptionsRequest
extends WorkDocsRequest
implements ToCopyableBuilder<DescribeNotificationSubscriptionsRequest.Builder,DescribeNotificationSubscriptionsRequest>
-
Nested Class Summary
Nested ClassesModifier and TypeClassDescriptionstatic interface -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final Integerlimit()The maximum number of items to return with this call.final Stringmarker()The marker for the next set of results.final StringThe ID of the organization.static Class<? extends DescribeNotificationSubscriptionsRequest.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class software.amazon.awssdk.awscore.AwsRequest
overrideConfigurationMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
organizationId
The ID of the organization.
- Returns:
- The ID of the organization.
-
marker
The marker for the next set of results. (You received this marker from a previous call.)
- Returns:
- The marker for the next set of results. (You received this marker from a previous call.)
-
limit
The maximum number of items to return with this call.
- Returns:
- The maximum number of items to return with this call.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<DescribeNotificationSubscriptionsRequest.Builder,DescribeNotificationSubscriptionsRequest> - Specified by:
toBuilderin classWorkDocsRequest
-
builder
-
serializableBuilderClass
public static Class<? extends DescribeNotificationSubscriptionsRequest.Builder> serializableBuilderClass() -
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsRequest
-
equals
- Overrides:
equalsin classAwsRequest
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkRequest
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-