Interface DescribeNotificationSubscriptionsRequest.Builder
- All Superinterfaces:
AwsRequest.Builder,Buildable,CopyableBuilder<DescribeNotificationSubscriptionsRequest.Builder,,DescribeNotificationSubscriptionsRequest> SdkBuilder<DescribeNotificationSubscriptionsRequest.Builder,,DescribeNotificationSubscriptionsRequest> SdkPojo,SdkRequest.Builder,WorkDocsRequest.Builder
- Enclosing class:
- DescribeNotificationSubscriptionsRequest
@Mutable
@NotThreadSafe
public static interface DescribeNotificationSubscriptionsRequest.Builder
extends WorkDocsRequest.Builder, SdkPojo, CopyableBuilder<DescribeNotificationSubscriptionsRequest.Builder,DescribeNotificationSubscriptionsRequest>
-
Method Summary
Modifier and TypeMethodDescriptionThe maximum number of items to return with this call.The marker for the next set of results.organizationId(String organizationId) The ID of the organization.overrideConfiguration(Consumer<AwsRequestOverrideConfiguration.Builder> builderConsumer) overrideConfiguration(AwsRequestOverrideConfiguration overrideConfiguration) Methods inherited from interface software.amazon.awssdk.awscore.AwsRequest.Builder
overrideConfigurationMethods inherited from interface software.amazon.awssdk.utils.builder.CopyableBuilder
copyMethods inherited from interface software.amazon.awssdk.utils.builder.SdkBuilder
applyMutation, buildMethods inherited from interface software.amazon.awssdk.core.SdkPojo
equalsBySdkFields, sdkFieldNameToField, sdkFieldsMethods inherited from interface software.amazon.awssdk.services.workdocs.model.WorkDocsRequest.Builder
build
-
Method Details
-
organizationId
The ID of the organization.
- Parameters:
organizationId- The ID of the organization.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
marker
The marker for the next set of results. (You received this marker from a previous call.)
- Parameters:
marker- The marker for the next set of results. (You received this marker from a previous call.)- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
limit
The maximum number of items to return with this call.
- Parameters:
limit- The maximum number of items to return with this call.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
overrideConfiguration
DescribeNotificationSubscriptionsRequest.Builder overrideConfiguration(AwsRequestOverrideConfiguration overrideConfiguration) - Specified by:
overrideConfigurationin interfaceAwsRequest.Builder
-
overrideConfiguration
DescribeNotificationSubscriptionsRequest.Builder overrideConfiguration(Consumer<AwsRequestOverrideConfiguration.Builder> builderConsumer) - Specified by:
overrideConfigurationin interfaceAwsRequest.Builder
-