Interface DescribeResourcePermissionsRequest.Builder
- All Superinterfaces:
AwsRequest.Builder,Buildable,CopyableBuilder<DescribeResourcePermissionsRequest.Builder,,DescribeResourcePermissionsRequest> SdkBuilder<DescribeResourcePermissionsRequest.Builder,,DescribeResourcePermissionsRequest> SdkPojo,SdkRequest.Builder,WorkDocsRequest.Builder
- Enclosing class:
- DescribeResourcePermissionsRequest
@Mutable
@NotThreadSafe
public static interface DescribeResourcePermissionsRequest.Builder
extends WorkDocsRequest.Builder, SdkPojo, CopyableBuilder<DescribeResourcePermissionsRequest.Builder,DescribeResourcePermissionsRequest>
-
Method Summary
Modifier and TypeMethodDescriptionauthenticationToken(String authenticationToken) Amazon WorkDocs authentication token.The maximum number of items to return with this call.The marker for the next set of results.overrideConfiguration(Consumer<AwsRequestOverrideConfiguration.Builder> builderConsumer) overrideConfiguration(AwsRequestOverrideConfiguration overrideConfiguration) principalId(String principalId) The ID of the principal to filter permissions by.resourceId(String resourceId) The ID of the resource.Methods inherited from interface software.amazon.awssdk.awscore.AwsRequest.Builder
overrideConfigurationMethods inherited from interface software.amazon.awssdk.utils.builder.CopyableBuilder
copyMethods inherited from interface software.amazon.awssdk.utils.builder.SdkBuilder
applyMutation, buildMethods inherited from interface software.amazon.awssdk.core.SdkPojo
equalsBySdkFields, sdkFieldNameToField, sdkFieldsMethods inherited from interface software.amazon.awssdk.services.workdocs.model.WorkDocsRequest.Builder
build
-
Method Details
-
authenticationToken
Amazon WorkDocs authentication token. Not required when using Amazon Web Services administrator credentials to access the API.
- Parameters:
authenticationToken- Amazon WorkDocs authentication token. Not required when using Amazon Web Services administrator credentials to access the API.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
resourceId
The ID of the resource.
- Parameters:
resourceId- The ID of the resource.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
principalId
The ID of the principal to filter permissions by.
- Parameters:
principalId- The ID of the principal to filter permissions by.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
limit
The maximum number of items to return with this call.
- Parameters:
limit- The maximum number of items to return with this call.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
marker
The marker for the next set of results. (You received this marker from a previous call)
- Parameters:
marker- The marker for the next set of results. (You received this marker from a previous call)- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
overrideConfiguration
DescribeResourcePermissionsRequest.Builder overrideConfiguration(AwsRequestOverrideConfiguration overrideConfiguration) - Specified by:
overrideConfigurationin interfaceAwsRequest.Builder
-
overrideConfiguration
DescribeResourcePermissionsRequest.Builder overrideConfiguration(Consumer<AwsRequestOverrideConfiguration.Builder> builderConsumer) - Specified by:
overrideConfigurationin interfaceAwsRequest.Builder
-