Class DescribeUsersRequest
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<DescribeUsersRequest.Builder,DescribeUsersRequest>
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionfinal StringAmazon WorkDocs authentication token.static DescribeUsersRequest.Builderbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final Stringfields()A comma-separated list of values.final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final UserFilterTypeinclude()The state of the users.final StringThe state of the users.final Integerlimit()The maximum number of items to return.final Stringmarker()The marker for the next set of results.final OrderTypeorder()The order for the results.final StringThe order for the results.final StringThe ID of the organization.final Stringquery()A query to filter users by user name.static Class<? extends DescribeUsersRequest.Builder>final UserSortTypesort()The sorting criteria.final StringThe sorting criteria.final StringtoString()Returns a string representation of this object.final StringuserIds()The IDs of the users.Methods inherited from class software.amazon.awssdk.awscore.AwsRequest
overrideConfigurationMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
authenticationToken
Amazon WorkDocs authentication token. Not required when using Amazon Web Services administrator credentials to access the API.
- Returns:
- Amazon WorkDocs authentication token. Not required when using Amazon Web Services administrator credentials to access the API.
-
organizationId
The ID of the organization.
- Returns:
- The ID of the organization.
-
userIds
The IDs of the users.
- Returns:
- The IDs of the users.
-
query
A query to filter users by user name. Remember the following about the
UseridsandQueryparameters:-
If you don't use either parameter, the API returns a paginated list of all users on the site.
-
If you use both parameters, the API ignores the
Queryparameter. -
The
Useridparameter only returns user names that match a corresponding user ID. -
The
Queryparameter runs a "prefix" search for users by theGivenName,SurName, orUserNamefields included in a CreateUser API call. For example, querying onMareturns Márcia Oliveira, María García, and Mateo Jackson. If you use multiple characters, the API only returns data that matches all characters. For example, querying onMa Jonly returns Mateo Jackson.
- Returns:
- A query to filter users by user name. Remember the following about the
UseridsandQueryparameters:-
If you don't use either parameter, the API returns a paginated list of all users on the site.
-
If you use both parameters, the API ignores the
Queryparameter. -
The
Useridparameter only returns user names that match a corresponding user ID. -
The
Queryparameter runs a "prefix" search for users by theGivenName,SurName, orUserNamefields included in a CreateUser API call. For example, querying onMareturns Márcia Oliveira, María García, and Mateo Jackson. If you use multiple characters, the API only returns data that matches all characters. For example, querying onMa Jonly returns Mateo Jackson.
-
-
-
include
The state of the users. Specify "ALL" to include inactive users.
If the service returns an enum value that is not available in the current SDK version,
includewill returnUserFilterType.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromincludeAsString().- Returns:
- The state of the users. Specify "ALL" to include inactive users.
- See Also:
-
includeAsString
The state of the users. Specify "ALL" to include inactive users.
If the service returns an enum value that is not available in the current SDK version,
includewill returnUserFilterType.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromincludeAsString().- Returns:
- The state of the users. Specify "ALL" to include inactive users.
- See Also:
-
order
The order for the results.
If the service returns an enum value that is not available in the current SDK version,
orderwill returnOrderType.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromorderAsString().- Returns:
- The order for the results.
- See Also:
-
orderAsString
The order for the results.
If the service returns an enum value that is not available in the current SDK version,
orderwill returnOrderType.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromorderAsString().- Returns:
- The order for the results.
- See Also:
-
sort
The sorting criteria.
If the service returns an enum value that is not available in the current SDK version,
sortwill returnUserSortType.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromsortAsString().- Returns:
- The sorting criteria.
- See Also:
-
sortAsString
The sorting criteria.
If the service returns an enum value that is not available in the current SDK version,
sortwill returnUserSortType.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromsortAsString().- Returns:
- The sorting criteria.
- See Also:
-
marker
The marker for the next set of results. (You received this marker from a previous call.)
- Returns:
- The marker for the next set of results. (You received this marker from a previous call.)
-
limit
The maximum number of items to return.
- Returns:
- The maximum number of items to return.
-
fields
A comma-separated list of values. Specify "STORAGE_METADATA" to include the user storage quota and utilization information.
- Returns:
- A comma-separated list of values. Specify "STORAGE_METADATA" to include the user storage quota and utilization information.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<DescribeUsersRequest.Builder,DescribeUsersRequest> - Specified by:
toBuilderin classWorkDocsRequest
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsRequest
-
equals
- Overrides:
equalsin classAwsRequest
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkRequest
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-