Class DescribeUsersResponse
java.lang.Object
software.amazon.awssdk.core.SdkResponse
software.amazon.awssdk.awscore.AwsResponse
software.amazon.awssdk.services.workdocs.model.WorkDocsResponse
software.amazon.awssdk.services.workdocs.model.DescribeUsersResponse
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<DescribeUsersResponse.Builder,DescribeUsersResponse>
@Generated("software.amazon.awssdk:codegen")
public final class DescribeUsersResponse
extends WorkDocsResponse
implements ToCopyableBuilder<DescribeUsersResponse.Builder,DescribeUsersResponse>
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final booleanhasUsers()For responses, this returns true if the service returned a value for the Users property.final Stringmarker()The marker to use when requesting the next set of results.static Class<? extends DescribeUsersResponse.Builder>final StringtoString()Returns a string representation of this object.final LongDeprecated.users()The users.Methods inherited from class software.amazon.awssdk.services.workdocs.model.WorkDocsResponse
responseMetadataMethods inherited from class software.amazon.awssdk.core.SdkResponse
sdkHttpResponseMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
hasUsers
public final boolean hasUsers()For responses, this returns true if the service returned a value for the Users property. This DOES NOT check that the value is non-empty (for which, you should check theisEmpty()method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified. -
users
The users.
Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.
This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the
hasUsers()method.- Returns:
- The users.
-
totalNumberOfUsers
Deprecated.The total number of users included in the results.
- Returns:
- The total number of users included in the results.
-
marker
The marker to use when requesting the next set of results. If there are no additional results, the string is empty.
- Returns:
- The marker to use when requesting the next set of results. If there are no additional results, the string is empty.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<DescribeUsersResponse.Builder,DescribeUsersResponse> - Specified by:
toBuilderin classAwsResponse
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsResponse
-
equals
- Overrides:
equalsin classAwsResponse
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkResponse
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-