Class EntityNotExistsException

All Implemented Interfaces:
Serializable, SdkPojo, ToCopyableBuilder<EntityNotExistsException.Builder,EntityNotExistsException>

@Generated("software.amazon.awssdk:codegen") public final class EntityNotExistsException extends WorkDocsException implements ToCopyableBuilder<EntityNotExistsException.Builder,EntityNotExistsException>

The resource does not exist.

See Also:
  • Method Details

    • toBuilder

      Specified by:
      toBuilder in interface ToCopyableBuilder<EntityNotExistsException.Builder,EntityNotExistsException>
      Overrides:
      toBuilder in class WorkDocsException
    • builder

      public static EntityNotExistsException.Builder builder()
    • serializableBuilderClass

      public static Class<? extends EntityNotExistsException.Builder> serializableBuilderClass()
    • hasEntityIds

      public boolean hasEntityIds()
      For responses, this returns true if the service returned a value for the EntityIds property. This DOES NOT check that the value is non-empty (for which, you should check the isEmpty() method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified.
    • entityIds

      public List<String> entityIds()

      The IDs of the non-existent resources.

      Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.

      This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the hasEntityIds() method.

      Returns:
      The IDs of the non-existent resources.
    • sdkFields

      public final List<SdkField<?>> sdkFields()
      Specified by:
      sdkFields in interface SdkPojo
      Overrides:
      sdkFields in class SdkServiceException
    • sdkFieldNameToField

      public final Map<String,SdkField<?>> sdkFieldNameToField()
      Specified by:
      sdkFieldNameToField in interface SdkPojo