Class GetDocumentRequest
java.lang.Object
software.amazon.awssdk.core.SdkRequest
software.amazon.awssdk.awscore.AwsRequest
software.amazon.awssdk.services.workdocs.model.WorkDocsRequest
software.amazon.awssdk.services.workdocs.model.GetDocumentRequest
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<GetDocumentRequest.Builder,GetDocumentRequest>
@Generated("software.amazon.awssdk:codegen")
public final class GetDocumentRequest
extends WorkDocsRequest
implements ToCopyableBuilder<GetDocumentRequest.Builder,GetDocumentRequest>
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionfinal StringAmazon WorkDocs authentication token.static GetDocumentRequest.Builderbuilder()final StringThe ID of the document.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final BooleanSet this toTRUEto include custom metadata in the response.static Class<? extends GetDocumentRequest.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class software.amazon.awssdk.awscore.AwsRequest
overrideConfigurationMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
authenticationToken
Amazon WorkDocs authentication token. Not required when using Amazon Web Services administrator credentials to access the API.
- Returns:
- Amazon WorkDocs authentication token. Not required when using Amazon Web Services administrator credentials to access the API.
-
documentId
The ID of the document.
- Returns:
- The ID of the document.
-
includeCustomMetadata
Set this to
TRUEto include custom metadata in the response.- Returns:
- Set this to
TRUEto include custom metadata in the response.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<GetDocumentRequest.Builder,GetDocumentRequest> - Specified by:
toBuilderin classWorkDocsRequest
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsRequest
-
equals
- Overrides:
equalsin classAwsRequest
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkRequest
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-