Class GetFolderPathRequest

All Implemented Interfaces:
SdkPojo, ToCopyableBuilder<GetFolderPathRequest.Builder,GetFolderPathRequest>

@Generated("software.amazon.awssdk:codegen") public final class GetFolderPathRequest extends WorkDocsRequest implements ToCopyableBuilder<GetFolderPathRequest.Builder,GetFolderPathRequest>
  • Method Details

    • authenticationToken

      public final String authenticationToken()

      Amazon WorkDocs authentication token. Not required when using Amazon Web Services administrator credentials to access the API.

      Returns:
      Amazon WorkDocs authentication token. Not required when using Amazon Web Services administrator credentials to access the API.
    • folderId

      public final String folderId()

      The ID of the folder.

      Returns:
      The ID of the folder.
    • limit

      public final Integer limit()

      The maximum number of levels in the hierarchy to return.

      Returns:
      The maximum number of levels in the hierarchy to return.
    • fields

      public final String fields()

      A comma-separated list of values. Specify "NAME" to include the names of the parent folders.

      Returns:
      A comma-separated list of values. Specify "NAME" to include the names of the parent folders.
    • marker

      public final String marker()

      This value is not supported.

      Returns:
      This value is not supported.
    • toBuilder

      public GetFolderPathRequest.Builder toBuilder()
      Specified by:
      toBuilder in interface ToCopyableBuilder<GetFolderPathRequest.Builder,GetFolderPathRequest>
      Specified by:
      toBuilder in class WorkDocsRequest
    • builder

      public static GetFolderPathRequest.Builder builder()
    • serializableBuilderClass

      public static Class<? extends GetFolderPathRequest.Builder> serializableBuilderClass()
    • hashCode

      public final int hashCode()
      Overrides:
      hashCode in class AwsRequest
    • equals

      public final boolean equals(Object obj)
      Overrides:
      equals in class AwsRequest
    • equalsBySdkFields

      public final boolean equalsBySdkFields(Object obj)
      Specified by:
      equalsBySdkFields in interface SdkPojo
    • toString

      public final String toString()
      Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
      Overrides:
      toString in class Object
    • getValueForField

      public final <T> Optional<T> getValueForField(String fieldName, Class<T> clazz)
      Overrides:
      getValueForField in class SdkRequest
    • sdkFields

      public final List<SdkField<?>> sdkFields()
      Specified by:
      sdkFields in interface SdkPojo
    • sdkFieldNameToField

      public final Map<String,SdkField<?>> sdkFieldNameToField()
      Specified by:
      sdkFieldNameToField in interface SdkPojo