Class RemoveResourcePermissionRequest
java.lang.Object
software.amazon.awssdk.core.SdkRequest
software.amazon.awssdk.awscore.AwsRequest
software.amazon.awssdk.services.workdocs.model.WorkDocsRequest
software.amazon.awssdk.services.workdocs.model.RemoveResourcePermissionRequest
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<RemoveResourcePermissionRequest.Builder,RemoveResourcePermissionRequest>
@Generated("software.amazon.awssdk:codegen")
public final class RemoveResourcePermissionRequest
extends WorkDocsRequest
implements ToCopyableBuilder<RemoveResourcePermissionRequest.Builder,RemoveResourcePermissionRequest>
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionfinal StringAmazon WorkDocs authentication token.builder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final StringThe principal ID of the resource.final PrincipalTypeThe principal type of the resource.final StringThe principal type of the resource.final StringThe ID of the resource.static Class<? extends RemoveResourcePermissionRequest.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class software.amazon.awssdk.awscore.AwsRequest
overrideConfigurationMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
authenticationToken
Amazon WorkDocs authentication token. Not required when using Amazon Web Services administrator credentials to access the API.
- Returns:
- Amazon WorkDocs authentication token. Not required when using Amazon Web Services administrator credentials to access the API.
-
resourceId
The ID of the resource.
- Returns:
- The ID of the resource.
-
principalId
The principal ID of the resource.
- Returns:
- The principal ID of the resource.
-
principalType
The principal type of the resource.
If the service returns an enum value that is not available in the current SDK version,
principalTypewill returnPrincipalType.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromprincipalTypeAsString().- Returns:
- The principal type of the resource.
- See Also:
-
principalTypeAsString
The principal type of the resource.
If the service returns an enum value that is not available in the current SDK version,
principalTypewill returnPrincipalType.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromprincipalTypeAsString().- Returns:
- The principal type of the resource.
- See Also:
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<RemoveResourcePermissionRequest.Builder,RemoveResourcePermissionRequest> - Specified by:
toBuilderin classWorkDocsRequest
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsRequest
-
equals
- Overrides:
equalsin classAwsRequest
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkRequest
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-