Interface UpdateDocumentVersionRequest.Builder
- All Superinterfaces:
AwsRequest.Builder,Buildable,CopyableBuilder<UpdateDocumentVersionRequest.Builder,,UpdateDocumentVersionRequest> SdkBuilder<UpdateDocumentVersionRequest.Builder,,UpdateDocumentVersionRequest> SdkPojo,SdkRequest.Builder,WorkDocsRequest.Builder
- Enclosing class:
- UpdateDocumentVersionRequest
@Mutable
@NotThreadSafe
public static interface UpdateDocumentVersionRequest.Builder
extends WorkDocsRequest.Builder, SdkPojo, CopyableBuilder<UpdateDocumentVersionRequest.Builder,UpdateDocumentVersionRequest>
-
Method Summary
Modifier and TypeMethodDescriptionauthenticationToken(String authenticationToken) Amazon WorkDocs authentication token.documentId(String documentId) The ID of the document.overrideConfiguration(Consumer<AwsRequestOverrideConfiguration.Builder> builderConsumer) overrideConfiguration(AwsRequestOverrideConfiguration overrideConfiguration) The version ID of the document.versionStatus(String versionStatus) The status of the version.versionStatus(DocumentVersionStatus versionStatus) The status of the version.Methods inherited from interface software.amazon.awssdk.awscore.AwsRequest.Builder
overrideConfigurationMethods inherited from interface software.amazon.awssdk.utils.builder.CopyableBuilder
copyMethods inherited from interface software.amazon.awssdk.utils.builder.SdkBuilder
applyMutation, buildMethods inherited from interface software.amazon.awssdk.core.SdkPojo
equalsBySdkFields, sdkFieldNameToField, sdkFieldsMethods inherited from interface software.amazon.awssdk.services.workdocs.model.WorkDocsRequest.Builder
build
-
Method Details
-
authenticationToken
Amazon WorkDocs authentication token. Not required when using Amazon Web Services administrator credentials to access the API.
- Parameters:
authenticationToken- Amazon WorkDocs authentication token. Not required when using Amazon Web Services administrator credentials to access the API.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
documentId
The ID of the document.
- Parameters:
documentId- The ID of the document.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
versionId
The version ID of the document.
- Parameters:
versionId- The version ID of the document.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
versionStatus
The status of the version.
- Parameters:
versionStatus- The status of the version.- Returns:
- Returns a reference to this object so that method calls can be chained together.
- See Also:
-
versionStatus
The status of the version.
- Parameters:
versionStatus- The status of the version.- Returns:
- Returns a reference to this object so that method calls can be chained together.
- See Also:
-
overrideConfiguration
UpdateDocumentVersionRequest.Builder overrideConfiguration(AwsRequestOverrideConfiguration overrideConfiguration) - Specified by:
overrideConfigurationin interfaceAwsRequest.Builder
-
overrideConfiguration
UpdateDocumentVersionRequest.Builder overrideConfiguration(Consumer<AwsRequestOverrideConfiguration.Builder> builderConsumer) - Specified by:
overrideConfigurationin interfaceAwsRequest.Builder
-