Class UpdateFolderRequest

All Implemented Interfaces:
SdkPojo, ToCopyableBuilder<UpdateFolderRequest.Builder,UpdateFolderRequest>

@Generated("software.amazon.awssdk:codegen") public final class UpdateFolderRequest extends WorkDocsRequest implements ToCopyableBuilder<UpdateFolderRequest.Builder,UpdateFolderRequest>
  • Method Details

    • authenticationToken

      public final String authenticationToken()

      Amazon WorkDocs authentication token. Not required when using Amazon Web Services administrator credentials to access the API.

      Returns:
      Amazon WorkDocs authentication token. Not required when using Amazon Web Services administrator credentials to access the API.
    • folderId

      public final String folderId()

      The ID of the folder.

      Returns:
      The ID of the folder.
    • name

      public final String name()

      The name of the folder.

      Returns:
      The name of the folder.
    • parentFolderId

      public final String parentFolderId()

      The ID of the parent folder.

      Returns:
      The ID of the parent folder.
    • resourceState

      public final ResourceStateType resourceState()

      The resource state of the folder. Only ACTIVE and RECYCLED are accepted values from the API.

      If the service returns an enum value that is not available in the current SDK version, resourceState will return ResourceStateType.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available from resourceStateAsString().

      Returns:
      The resource state of the folder. Only ACTIVE and RECYCLED are accepted values from the API.
      See Also:
    • resourceStateAsString

      public final String resourceStateAsString()

      The resource state of the folder. Only ACTIVE and RECYCLED are accepted values from the API.

      If the service returns an enum value that is not available in the current SDK version, resourceState will return ResourceStateType.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available from resourceStateAsString().

      Returns:
      The resource state of the folder. Only ACTIVE and RECYCLED are accepted values from the API.
      See Also:
    • toBuilder

      public UpdateFolderRequest.Builder toBuilder()
      Specified by:
      toBuilder in interface ToCopyableBuilder<UpdateFolderRequest.Builder,UpdateFolderRequest>
      Specified by:
      toBuilder in class WorkDocsRequest
    • builder

      public static UpdateFolderRequest.Builder builder()
    • serializableBuilderClass

      public static Class<? extends UpdateFolderRequest.Builder> serializableBuilderClass()
    • hashCode

      public final int hashCode()
      Overrides:
      hashCode in class AwsRequest
    • equals

      public final boolean equals(Object obj)
      Overrides:
      equals in class AwsRequest
    • equalsBySdkFields

      public final boolean equalsBySdkFields(Object obj)
      Specified by:
      equalsBySdkFields in interface SdkPojo
    • toString

      public final String toString()
      Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
      Overrides:
      toString in class Object
    • getValueForField

      public final <T> Optional<T> getValueForField(String fieldName, Class<T> clazz)
      Overrides:
      getValueForField in class SdkRequest
    • sdkFields

      public final List<SdkField<?>> sdkFields()
      Specified by:
      sdkFields in interface SdkPojo
    • sdkFieldNameToField

      public final Map<String,SdkField<?>> sdkFieldNameToField()
      Specified by:
      sdkFieldNameToField in interface SdkPojo