Interface UpdateFolderRequest.Builder

All Superinterfaces:
AwsRequest.Builder, Buildable, CopyableBuilder<UpdateFolderRequest.Builder,UpdateFolderRequest>, SdkBuilder<UpdateFolderRequest.Builder,UpdateFolderRequest>, SdkPojo, SdkRequest.Builder, WorkDocsRequest.Builder
Enclosing class:
UpdateFolderRequest

  • Method Details

    • authenticationToken

      UpdateFolderRequest.Builder authenticationToken(String authenticationToken)

      Amazon WorkDocs authentication token. Not required when using Amazon Web Services administrator credentials to access the API.

      Parameters:
      authenticationToken - Amazon WorkDocs authentication token. Not required when using Amazon Web Services administrator credentials to access the API.
      Returns:
      Returns a reference to this object so that method calls can be chained together.
    • folderId

      UpdateFolderRequest.Builder folderId(String folderId)

      The ID of the folder.

      Parameters:
      folderId - The ID of the folder.
      Returns:
      Returns a reference to this object so that method calls can be chained together.
    • name

      The name of the folder.

      Parameters:
      name - The name of the folder.
      Returns:
      Returns a reference to this object so that method calls can be chained together.
    • parentFolderId

      UpdateFolderRequest.Builder parentFolderId(String parentFolderId)

      The ID of the parent folder.

      Parameters:
      parentFolderId - The ID of the parent folder.
      Returns:
      Returns a reference to this object so that method calls can be chained together.
    • resourceState

      UpdateFolderRequest.Builder resourceState(String resourceState)

      The resource state of the folder. Only ACTIVE and RECYCLED are accepted values from the API.

      Parameters:
      resourceState - The resource state of the folder. Only ACTIVE and RECYCLED are accepted values from the API.
      Returns:
      Returns a reference to this object so that method calls can be chained together.
      See Also:
    • resourceState

      UpdateFolderRequest.Builder resourceState(ResourceStateType resourceState)

      The resource state of the folder. Only ACTIVE and RECYCLED are accepted values from the API.

      Parameters:
      resourceState - The resource state of the folder. Only ACTIVE and RECYCLED are accepted values from the API.
      Returns:
      Returns a reference to this object so that method calls can be chained together.
      See Also:
    • overrideConfiguration

      UpdateFolderRequest.Builder overrideConfiguration(AwsRequestOverrideConfiguration overrideConfiguration)
      Specified by:
      overrideConfiguration in interface AwsRequest.Builder
    • overrideConfiguration

      Specified by:
      overrideConfiguration in interface AwsRequest.Builder