Class UpdateUserRequest

All Implemented Interfaces:
SdkPojo, ToCopyableBuilder<UpdateUserRequest.Builder,UpdateUserRequest>

@Generated("software.amazon.awssdk:codegen") public final class UpdateUserRequest extends WorkDocsRequest implements ToCopyableBuilder<UpdateUserRequest.Builder,UpdateUserRequest>
  • Method Details

    • authenticationToken

      public final String authenticationToken()

      Amazon WorkDocs authentication token. Not required when using Amazon Web Services administrator credentials to access the API.

      Returns:
      Amazon WorkDocs authentication token. Not required when using Amazon Web Services administrator credentials to access the API.
    • userId

      public final String userId()

      The ID of the user.

      Returns:
      The ID of the user.
    • givenName

      public final String givenName()

      The given name of the user.

      Returns:
      The given name of the user.
    • surname

      public final String surname()

      The surname of the user.

      Returns:
      The surname of the user.
    • type

      public final UserType type()

      The type of the user.

      If the service returns an enum value that is not available in the current SDK version, type will return UserType.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available from typeAsString().

      Returns:
      The type of the user.
      See Also:
    • typeAsString

      public final String typeAsString()

      The type of the user.

      If the service returns an enum value that is not available in the current SDK version, type will return UserType.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available from typeAsString().

      Returns:
      The type of the user.
      See Also:
    • storageRule

      public final StorageRuleType storageRule()

      The amount of storage for the user.

      Returns:
      The amount of storage for the user.
    • timeZoneId

      public final String timeZoneId()

      The time zone ID of the user.

      Returns:
      The time zone ID of the user.
    • locale

      public final LocaleType locale()

      The locale of the user.

      If the service returns an enum value that is not available in the current SDK version, locale will return LocaleType.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available from localeAsString().

      Returns:
      The locale of the user.
      See Also:
    • localeAsString

      public final String localeAsString()

      The locale of the user.

      If the service returns an enum value that is not available in the current SDK version, locale will return LocaleType.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available from localeAsString().

      Returns:
      The locale of the user.
      See Also:
    • grantPoweruserPrivileges

      public final BooleanEnumType grantPoweruserPrivileges()

      Boolean value to determine whether the user is granted Power user privileges.

      If the service returns an enum value that is not available in the current SDK version, grantPoweruserPrivileges will return BooleanEnumType.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available from grantPoweruserPrivilegesAsString().

      Returns:
      Boolean value to determine whether the user is granted Power user privileges.
      See Also:
    • grantPoweruserPrivilegesAsString

      public final String grantPoweruserPrivilegesAsString()

      Boolean value to determine whether the user is granted Power user privileges.

      If the service returns an enum value that is not available in the current SDK version, grantPoweruserPrivileges will return BooleanEnumType.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available from grantPoweruserPrivilegesAsString().

      Returns:
      Boolean value to determine whether the user is granted Power user privileges.
      See Also:
    • toBuilder

      public UpdateUserRequest.Builder toBuilder()
      Specified by:
      toBuilder in interface ToCopyableBuilder<UpdateUserRequest.Builder,UpdateUserRequest>
      Specified by:
      toBuilder in class WorkDocsRequest
    • builder

      public static UpdateUserRequest.Builder builder()
    • serializableBuilderClass

      public static Class<? extends UpdateUserRequest.Builder> serializableBuilderClass()
    • hashCode

      public final int hashCode()
      Overrides:
      hashCode in class AwsRequest
    • equals

      public final boolean equals(Object obj)
      Overrides:
      equals in class AwsRequest
    • equalsBySdkFields

      public final boolean equalsBySdkFields(Object obj)
      Specified by:
      equalsBySdkFields in interface SdkPojo
    • toString

      public final String toString()
      Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
      Overrides:
      toString in class Object
    • getValueForField

      public final <T> Optional<T> getValueForField(String fieldName, Class<T> clazz)
      Overrides:
      getValueForField in class SdkRequest
    • sdkFields

      public final List<SdkField<?>> sdkFields()
      Specified by:
      sdkFields in interface SdkPojo
    • sdkFieldNameToField

      public final Map<String,SdkField<?>> sdkFieldNameToField()
      Specified by:
      sdkFieldNameToField in interface SdkPojo