Uses of Class
software.amazon.awssdk.services.workdocs.model.CreateFolderResponse
Packages that use CreateFolderResponse
Package
Description
The Amazon WorkDocs API is designed for the following use cases:
-
Uses of CreateFolderResponse in software.amazon.awssdk.services.workdocs
Methods in software.amazon.awssdk.services.workdocs that return CreateFolderResponseModifier and TypeMethodDescriptiondefault CreateFolderResponseWorkDocsClient.createFolder(Consumer<CreateFolderRequest.Builder> createFolderRequest) Creates a folder with the specified name and parent folder.default CreateFolderResponseWorkDocsClient.createFolder(CreateFolderRequest createFolderRequest) Creates a folder with the specified name and parent folder.Methods in software.amazon.awssdk.services.workdocs that return types with arguments of type CreateFolderResponseModifier and TypeMethodDescriptiondefault CompletableFuture<CreateFolderResponse>WorkDocsAsyncClient.createFolder(Consumer<CreateFolderRequest.Builder> createFolderRequest) Creates a folder with the specified name and parent folder.default CompletableFuture<CreateFolderResponse>WorkDocsAsyncClient.createFolder(CreateFolderRequest createFolderRequest) Creates a folder with the specified name and parent folder.