Uses of Class
software.amazon.awssdk.services.workdocs.model.DescribeNotificationSubscriptionsResponse
Packages that use DescribeNotificationSubscriptionsResponse
Package
Description
The Amazon WorkDocs API is designed for the following use cases:
-
Uses of DescribeNotificationSubscriptionsResponse in software.amazon.awssdk.services.workdocs
Methods in software.amazon.awssdk.services.workdocs that return DescribeNotificationSubscriptionsResponseModifier and TypeMethodDescriptionWorkDocsClient.describeNotificationSubscriptions(Consumer<DescribeNotificationSubscriptionsRequest.Builder> describeNotificationSubscriptionsRequest) Lists the specified notification subscriptions.WorkDocsClient.describeNotificationSubscriptions(DescribeNotificationSubscriptionsRequest describeNotificationSubscriptionsRequest) Lists the specified notification subscriptions.Methods in software.amazon.awssdk.services.workdocs that return types with arguments of type DescribeNotificationSubscriptionsResponseModifier and TypeMethodDescriptionWorkDocsAsyncClient.describeNotificationSubscriptions(Consumer<DescribeNotificationSubscriptionsRequest.Builder> describeNotificationSubscriptionsRequest) Lists the specified notification subscriptions.WorkDocsAsyncClient.describeNotificationSubscriptions(DescribeNotificationSubscriptionsRequest describeNotificationSubscriptionsRequest) Lists the specified notification subscriptions. -
Uses of DescribeNotificationSubscriptionsResponse in software.amazon.awssdk.services.workdocs.paginators
Methods in software.amazon.awssdk.services.workdocs.paginators that return types with arguments of type DescribeNotificationSubscriptionsResponseMethod parameters in software.amazon.awssdk.services.workdocs.paginators with type arguments of type DescribeNotificationSubscriptionsResponseModifier and TypeMethodDescriptionvoidDescribeNotificationSubscriptionsPublisher.subscribe(org.reactivestreams.Subscriber<? super DescribeNotificationSubscriptionsResponse> subscriber)