Uses of Class
software.amazon.awssdk.services.workdocs.model.UpdateUserResponse
Packages that use UpdateUserResponse
Package
Description
The Amazon WorkDocs API is designed for the following use cases:
-
Uses of UpdateUserResponse in software.amazon.awssdk.services.workdocs
Methods in software.amazon.awssdk.services.workdocs that return UpdateUserResponseModifier and TypeMethodDescriptiondefault UpdateUserResponseWorkDocsClient.updateUser(Consumer<UpdateUserRequest.Builder> updateUserRequest) Updates the specified attributes of the specified user, and grants or revokes administrative privileges to the Amazon WorkDocs site.default UpdateUserResponseWorkDocsClient.updateUser(UpdateUserRequest updateUserRequest) Updates the specified attributes of the specified user, and grants or revokes administrative privileges to the Amazon WorkDocs site.Methods in software.amazon.awssdk.services.workdocs that return types with arguments of type UpdateUserResponseModifier and TypeMethodDescriptiondefault CompletableFuture<UpdateUserResponse>WorkDocsAsyncClient.updateUser(Consumer<UpdateUserRequest.Builder> updateUserRequest) Updates the specified attributes of the specified user, and grants or revokes administrative privileges to the Amazon WorkDocs site.default CompletableFuture<UpdateUserResponse>WorkDocsAsyncClient.updateUser(UpdateUserRequest updateUserRequest) Updates the specified attributes of the specified user, and grants or revokes administrative privileges to the Amazon WorkDocs site.