All Classes and Interfaces
Class
Description
AbortDocumentVersionUploadRequest MarshallerActivateUserRequest Marshaller
Describes the activity information.
AddResourcePermissionsRequest MarshallerAn AWS Arn.
Describes a comment.
Describes the metadata of a comment.
The resource hierarchy is changing.
Another operation is in progress on the resource that conflicts with the current operation.
CreateCommentRequest MarshallerCreateCustomMetadataRequest MarshallerCreateFolderRequest MarshallerCreateLabelsRequest MarshallerCreateNotificationSubscriptionRequest MarshallerCreateUserRequest Marshaller
The limit has been reached on the number of custom properties for the specified resource.
Filters results based on timestamp range (in epochs).
DeactivateUserRequest Marshaller
The last user in the organization is being deactivated.
DeleteCommentRequest MarshallerDeleteCustomMetadataRequest MarshallerDeleteDocumentRequest MarshallerDeleteDocumentVersionRequest MarshallerDeleteFolderContentsRequest MarshallerDeleteFolderRequest MarshallerDeleteLabelsRequest MarshallerDeleteNotificationSubscriptionRequest MarshallerDeleteUserRequest Marshaller
Represents the output for the
WorkDocsClient.describeActivitiesPaginator(software.amazon.awssdk.services.workdocs.model.DescribeActivitiesRequest)
operation which is a paginated operation.
Represents the output for the
WorkDocsAsyncClient.describeActivitiesPaginator(software.amazon.awssdk.services.workdocs.model.DescribeActivitiesRequest)
operation which is a paginated operation.DescribeActivitiesRequest Marshaller
Represents the output for the
WorkDocsClient.describeCommentsPaginator(software.amazon.awssdk.services.workdocs.model.DescribeCommentsRequest)
operation which is a paginated operation.
Represents the output for the
WorkDocsAsyncClient.describeCommentsPaginator(software.amazon.awssdk.services.workdocs.model.DescribeCommentsRequest)
operation which is a paginated operation.DescribeCommentsRequest Marshaller
Represents the output for the
WorkDocsClient.describeDocumentVersionsPaginator(software.amazon.awssdk.services.workdocs.model.DescribeDocumentVersionsRequest)
operation which is a paginated operation.
Represents the output for the
WorkDocsAsyncClient.describeDocumentVersionsPaginator(software.amazon.awssdk.services.workdocs.model.DescribeDocumentVersionsRequest)
operation which is a paginated operation.DescribeDocumentVersionsRequest Marshaller
Represents the output for the
WorkDocsClient.describeFolderContentsPaginator(software.amazon.awssdk.services.workdocs.model.DescribeFolderContentsRequest)
operation which is a paginated operation.
Represents the output for the
WorkDocsAsyncClient.describeFolderContentsPaginator(software.amazon.awssdk.services.workdocs.model.DescribeFolderContentsRequest)
operation which is a paginated operation.DescribeFolderContentsRequest Marshaller
Represents the output for the
WorkDocsClient.describeGroupsPaginator(software.amazon.awssdk.services.workdocs.model.DescribeGroupsRequest)
operation which is a paginated operation.
Represents the output for the
WorkDocsAsyncClient.describeGroupsPaginator(software.amazon.awssdk.services.workdocs.model.DescribeGroupsRequest)
operation which is a paginated operation.DescribeGroupsRequest Marshaller
Represents the output for the
WorkDocsClient.describeNotificationSubscriptionsPaginator(software.amazon.awssdk.services.workdocs.model.DescribeNotificationSubscriptionsRequest)
operation which is a paginated operation.
Represents the output for the
WorkDocsAsyncClient.describeNotificationSubscriptionsPaginator(software.amazon.awssdk.services.workdocs.model.DescribeNotificationSubscriptionsRequest)
operation which is a paginated operation.DescribeNotificationSubscriptionsRequest Marshaller
Represents the output for the
WorkDocsClient.describeResourcePermissionsPaginator(software.amazon.awssdk.services.workdocs.model.DescribeResourcePermissionsRequest)
operation which is a paginated operation.
Represents the output for the
WorkDocsAsyncClient.describeResourcePermissionsPaginator(software.amazon.awssdk.services.workdocs.model.DescribeResourcePermissionsRequest)
operation which is a paginated operation.DescribeResourcePermissionsRequest Marshaller
Represents the output for the
WorkDocsClient.describeRootFoldersPaginator(software.amazon.awssdk.services.workdocs.model.DescribeRootFoldersRequest)
operation which is a paginated operation.
Represents the output for the
WorkDocsAsyncClient.describeRootFoldersPaginator(software.amazon.awssdk.services.workdocs.model.DescribeRootFoldersRequest)
operation which is a paginated operation.DescribeRootFoldersRequest Marshaller
Represents the output for the
WorkDocsClient.describeUsersPaginator(software.amazon.awssdk.services.workdocs.model.DescribeUsersRequest)
operation which is a paginated operation.
Represents the output for the
WorkDocsAsyncClient.describeUsersPaginator(software.amazon.awssdk.services.workdocs.model.DescribeUsersRequest)
operation which is a paginated operation.DescribeUsersRequest Marshaller
This exception is thrown when the document is locked for comments and user tries to create or delete a comment on
that document.
Describes the document.
Describes a version of a document.
This exception is thrown when a valid checkout ID is not presented on document version upload calls for a document
that has been checked out from Web client.
Link between an endpoint property and the
AwsEndpointAttribute it represents.
The resource already exists.
The resource does not exist.
The Directory Service cannot reach an on-premises instance.
Filters results based on entity metadata.
Describes a folder.
GetCurrentUserRequest MarshallerGetDocumentPathRequest MarshallerGetDocumentRequest MarshallerGetDocumentVersionRequest MarshallerGetFolderPathRequest MarshallerGetFolderRequest MarshallerGetResourcesRequest Marshaller
Describes the metadata of a user group.
Identifiers for variables declared within the rule engine, e.g.
The user is undergoing transfer of ownership.
InitiateDocumentVersionUploadRequest Marshaller
The pagination marker or limit fields are not valid.
The requested operation is not allowed on the specified comment object.
The operation is invalid.
The password is invalid.
The maximum of 100,000 files and folders under the parent folder has been exceeded.
Filter based on size (in bytes).
Set of options which defines notification preferences of given action.
Describes the users or user groups.
Describes the permissions.
Describes a resource.
The specified document version is not in the INITIALIZED state.
RemoveAllResourcePermissionsRequest MarshallerRemoveResourcePermissionRequest Marshaller
The response is too large to return.
The resource is already checked out.
Describes the metadata of a resource.
Describes the path information of a resource.
Describes the resource path.
List of Documents, Folders, Comments, and Document Versions matching the query.
RestoreDocumentVersionsRequest MarshallerRepresents a URL to be used internally for endpoint resolution.
Filter based on UserIds or GroupIds.
Represents the output for the
WorkDocsClient.searchResourcesPaginator(software.amazon.awssdk.services.workdocs.model.SearchResourcesRequest)
operation which is a paginated operation.
Represents the output for the
WorkDocsAsyncClient.searchResourcesPaginator(software.amazon.awssdk.services.workdocs.model.SearchResourcesRequest)
operation which is a paginated operation.SearchResourcesRequest Marshaller
The result of the sort operation.
One or more of the dependencies is unavailable.
Describes the recipient type and ID, if available.
Describes the share results of a resource.
The storage limit has been exceeded.
The storage limit will be exceeded.
Describes the storage for a user.
Describes a subscription.
The limit has been reached on the number of labels for the specified resource.
You've reached the limit on the number of subscriptions for the WorkDocs instance.
The operation is not permitted.
The caller does not have access to perform the action on the resource.
UpdateDocumentRequest MarshallerUpdateDocumentVersionRequest MarshallerUpdateFolderRequest MarshallerUpdateUserRequest Marshaller
Describes the upload.
Describes a user.
Describes the metadata of the user.
Describes the storage for a user.
Base class for the types of values computable by the
RuleEngine.An array value.
A boolean value.
An integer value.
A record (map) value.
A string value.
Service client for accessing Amazon WorkDocs asynchronously.
A builder for creating an instance of
WorkDocsAsyncClient.The parameters object used to resolve the auth schemes for the WorkDocs service.
A builder for a
WorkDocsAuthSchemeParams.An auth scheme provider for WorkDocs service.
This includes configuration specific to Amazon WorkDocs that is supported by both
WorkDocsClientBuilder and
WorkDocsAsyncClientBuilder.Service client for accessing Amazon WorkDocs.
A builder for creating an instance of
WorkDocsClient.The parameters object used to resolve an endpoint for the WorkDocs service.
An endpoint provider for WorkDocs.
Class to expose the service client settings to the user.
A builder for creating a
WorkDocsServiceClientConfiguration