Class UpdateFolderRequest
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<UpdateFolderRequest.Builder,UpdateFolderRequest>
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionfinal StringAmazon WorkDocs authentication token.static UpdateFolderRequest.Builderbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final StringfolderId()The ID of the folder.final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final Stringname()The name of the folder.final StringThe ID of the parent folder.final ResourceStateTypeThe resource state of the folder.final StringThe resource state of the folder.static Class<? extends UpdateFolderRequest.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class software.amazon.awssdk.awscore.AwsRequest
overrideConfigurationMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
authenticationToken
Amazon WorkDocs authentication token. Not required when using Amazon Web Services administrator credentials to access the API.
- Returns:
- Amazon WorkDocs authentication token. Not required when using Amazon Web Services administrator credentials to access the API.
-
folderId
The ID of the folder.
- Returns:
- The ID of the folder.
-
name
The name of the folder.
- Returns:
- The name of the folder.
-
parentFolderId
The ID of the parent folder.
- Returns:
- The ID of the parent folder.
-
resourceState
The resource state of the folder. Only ACTIVE and RECYCLED are accepted values from the API.
If the service returns an enum value that is not available in the current SDK version,
resourceStatewill returnResourceStateType.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromresourceStateAsString().- Returns:
- The resource state of the folder. Only ACTIVE and RECYCLED are accepted values from the API.
- See Also:
-
resourceStateAsString
The resource state of the folder. Only ACTIVE and RECYCLED are accepted values from the API.
If the service returns an enum value that is not available in the current SDK version,
resourceStatewill returnResourceStateType.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromresourceStateAsString().- Returns:
- The resource state of the folder. Only ACTIVE and RECYCLED are accepted values from the API.
- See Also:
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<UpdateFolderRequest.Builder,UpdateFolderRequest> - Specified by:
toBuilderin classWorkDocsRequest
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsRequest
-
equals
- Overrides:
equalsin classAwsRequest
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkRequest
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-