Class UpdateUserRequest
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<UpdateUserRequest.Builder,UpdateUserRequest>
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionfinal StringAmazon WorkDocs authentication token.static UpdateUserRequest.Builderbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final StringThe given name of the user.final BooleanEnumTypeBoolean value to determine whether the user is granted Power user privileges.final StringBoolean value to determine whether the user is granted Power user privileges.final inthashCode()final LocaleTypelocale()The locale of the user.final StringThe locale of the user.static Class<? extends UpdateUserRequest.Builder>final StorageRuleTypeThe amount of storage for the user.final Stringsurname()The surname of the user.final StringThe time zone ID of the user.final StringtoString()Returns a string representation of this object.final UserTypetype()The type of the user.final StringThe type of the user.final StringuserId()The ID of the user.Methods inherited from class software.amazon.awssdk.awscore.AwsRequest
overrideConfigurationMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
authenticationToken
Amazon WorkDocs authentication token. Not required when using Amazon Web Services administrator credentials to access the API.
- Returns:
- Amazon WorkDocs authentication token. Not required when using Amazon Web Services administrator credentials to access the API.
-
userId
The ID of the user.
- Returns:
- The ID of the user.
-
givenName
The given name of the user.
- Returns:
- The given name of the user.
-
surname
The surname of the user.
- Returns:
- The surname of the user.
-
type
The type of the user.
If the service returns an enum value that is not available in the current SDK version,
typewill returnUserType.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromtypeAsString().- Returns:
- The type of the user.
- See Also:
-
typeAsString
The type of the user.
If the service returns an enum value that is not available in the current SDK version,
typewill returnUserType.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromtypeAsString().- Returns:
- The type of the user.
- See Also:
-
storageRule
The amount of storage for the user.
- Returns:
- The amount of storage for the user.
-
timeZoneId
The time zone ID of the user.
- Returns:
- The time zone ID of the user.
-
locale
The locale of the user.
If the service returns an enum value that is not available in the current SDK version,
localewill returnLocaleType.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromlocaleAsString().- Returns:
- The locale of the user.
- See Also:
-
localeAsString
The locale of the user.
If the service returns an enum value that is not available in the current SDK version,
localewill returnLocaleType.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromlocaleAsString().- Returns:
- The locale of the user.
- See Also:
-
grantPoweruserPrivileges
Boolean value to determine whether the user is granted Power user privileges.
If the service returns an enum value that is not available in the current SDK version,
grantPoweruserPrivilegeswill returnBooleanEnumType.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromgrantPoweruserPrivilegesAsString().- Returns:
- Boolean value to determine whether the user is granted Power user privileges.
- See Also:
-
grantPoweruserPrivilegesAsString
Boolean value to determine whether the user is granted Power user privileges.
If the service returns an enum value that is not available in the current SDK version,
grantPoweruserPrivilegeswill returnBooleanEnumType.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromgrantPoweruserPrivilegesAsString().- Returns:
- Boolean value to determine whether the user is granted Power user privileges.
- See Also:
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<UpdateUserRequest.Builder,UpdateUserRequest> - Specified by:
toBuilderin classWorkDocsRequest
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsRequest
-
equals
- Overrides:
equalsin classAwsRequest
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkRequest
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-